@@ -1,6 +1,6 @@
-from django.contrib.auth import user_logged_in, user_logged_out, login, logout
+from django.contrib.auth import login, logout, user_logged_in, user_logged_out
 from django.utils.encoding import force_bytes, force_text
-from django.utils.http import urlsafe_base64_encode, urlsafe_base64_decode
+from django.utils.http import urlsafe_base64_decode, urlsafe_base64_encode
 
 from djoser.conf import settings
 
