@@ -1,14 +1,15 @@
 from django.contrib.auth import get_user_model
 from django.contrib.auth.tokens import default_token_generator
 from django.utils.timezone import now
-from djoser import signals, utils
-from djoser.compat import get_user_email
-from djoser.conf import settings
 from rest_framework import generics, status, views, viewsets
 from rest_framework.decorators import action
 from rest_framework.exceptions import NotFound
 from rest_framework.response import Response
 
+from djoser import signals, utils
+from djoser.compat import get_user_email
+from djoser.conf import settings
+
 User = get_user_model()
 
 
@@ -83,6 +84,10 @@ class UserViewSet(viewsets.ModelViewSet):
             self.permission_classes = settings.PERMISSIONS.username_reset
         elif self.action == "reset_username_confirm":
             self.permission_classes = settings.PERMISSIONS.username_reset_confirm
+        elif self.action == "destroy" or (
+            self.action == "me" and self.request and self.request.method == "DELETE"
+        ):
+            self.permission_classes = settings.PERMISSIONS.user_delete
         return super().get_permissions()
 
     def get_serializer_class(self):
@@ -90,7 +95,7 @@ class UserViewSet(viewsets.ModelViewSet):
             if settings.USER_CREATE_PASSWORD_RETYPE:
                 return settings.SERIALIZERS.user_create_password_retype
             return settings.SERIALIZERS.user_create
-        elif self.action == "remove" or (
+        elif self.action == "destroy" or (
             self.action == "me" and self.request and self.request.method == "DELETE"
         ):
             return settings.SERIALIZERS.user_delete
@@ -185,7 +190,7 @@ class UserViewSet(viewsets.ModelViewSet):
         if settings.SEND_CONFIRMATION_EMAIL:
             context = {"user": user}
             to = [get_user_email(user)]
-            settings.EMAIL.activation(self.request, context).send(to)
+            settings.EMAIL.confirmation(self.request, context).send(to)
 
         return Response(status=status.HTTP_204_NO_CONTENT)
 
